==> v2.3.4.tar.gz: privacyguides.org/docs/index.en.md <==
---
template: overrides/home.en.html
hide:
  - navigation
  - toc
---
<!-- markdownlint-disable-next-line -->
<div style="max-width:50rem;margin:auto;" markdown>
<div style="max-width:38rem;" markdown>
## Why should I care?

##### “I have nothing to hide. Why should I care about my privacy?”

Much like the right to interracial marriage, woman's suffrage, freedom of speech, and many others, we didn't always have the right to privacy. In several dictatorships, many still don't. Generations before ours fought for our right to privacy. ==Privacy is a human right inherent to all of us== that we are entitled to without discrimination.

You shouldn't confuse privacy with secrecy. We know what happens in the bathroom, but you still close the door. That's because you want privacy, not secrecy. **Everyone** has something to hide, privacy is something that makes you human.
</div>

<div style="margin-left:auto;margin-right:0;text-align:right;max-width:38rem;" markdown>
## What should I do?

##### First, you need to make a plan

Trying to protect all your data from everyone all the time is impractical, expensive, and exhausting. But don't worry! Security is a process, and by thinking ahead you can put together a plan that's right for you. Security isn't just about the tools you use or the software you download. Rather, it begins with understanding the unique threats you face, and how you can counter them.

==This process of identifying threats and defining countermeasures is called **threat modeling**==, and it forms the basis of every good security and privacy plan.

[:material-book-outline: Learn More About Threat Modeling](threat-modeling.md){ .md-button .md-button--primary }
</div>
</div>

<div style="padding-top:5em;max-width:960px;margin:auto;text-align:center;" markdown>
## We need you! Here's how to get involved

It's important for a website like Privacy Guides to always stay up-to-date. We need our audience to keep an eye on software updates for the applications listed on our site and follow recent news about providers that we recommend. It's hard to keep up with the fast pace of the internet, but we try our best. If you spot an error, think a provider should not be listed, notice a qualified provider is missing, believe a browser plugin is no longer the best choice, or uncover any other issue, please let us know.
</div>
<div class="grid cards" style="margin:auto;max-width:800px;text-align:center;" markdown>

- [:fontawesome-brands-reddit: Join the r/PrivacyGuides Subreddit](https://www.reddit.com/r/privacyguides)
- [:fontawesome-brands-twitter: Follow @Privacy_Guides on Twitter](https://twitter.com/privacy_guides)
- [:material-book-edit: Contribute to this website](https://github.com/privacyguides/privacyguides.org)
- [:material-chat: Chat with us on Matrix](https://matrix.to/#/#privacyguides:matrix.org)

</div>
<div style="padding:3em;text-align:center;" markdown>
## About Privacy Guides

**Privacy Guides** is a non-profit, socially motivated website that provides information for protecting your data security and privacy.

We do not make money from recommending certain products, and we do not utilize affiliate links. [Learn more :material-arrow-right:](about.md)
</div>

==> v2.24.tar.gz: privacyguides.org/docs/index.en.md <==
---
template: overrides/home.en.html
hide:
  - navigation
  - toc
  - feedback
---
<!-- markdownlint-disable-next-line -->
<div style="max-width:50rem;margin:auto;" markdown>
<div style="max-width:38rem;" markdown>
## Why should I care?

##### “I have nothing to hide. Why should I care about my privacy?”

Much like the right to interracial marriage, woman's suffrage, freedom of speech, and many others, we didn't always have the right to privacy. In several dictatorships, many still don't. Generations before ours fought for our right to privacy. ==Privacy is a human right inherent to all of us== that we are entitled to without discrimination.

You shouldn't confuse privacy with secrecy. We know what happens in the bathroom, but you still close the door. That's because you want privacy, not secrecy. **Everyone** has something to protect. Privacy is something that makes you human.

[:material-target-account: Common Internet Threats](basics/common-threats.md){ .md-button .md-button--primary }
</div>

<div style="margin-left:auto;margin-right:0;text-align:right;max-width:38rem;" markdown>
## What should I do?

##### First, you need to make a plan

Trying to protect all your data from everyone all the time is impractical, expensive, and exhausting. But don't worry! Security is a process, and by thinking ahead you can put together a plan that's right for you. Security isn't just about the tools you use or the software you download. Rather, it begins by understanding the unique threats you face, and how you can counter them.

==This process of identifying threats and defining countermeasures is called **threat modeling**==, and it forms the basis of every good security and privacy plan.

[:material-book-outline: Learn More About Threat Modeling](basics/threat-modeling.md){ .md-button .md-button--primary }
</div>
</div>

<div style="padding-top:5em;max-width:960px;margin:auto;text-align:center;" markdown>
## We need you! Here's how to get involved

It's important for a website like Privacy Guides to always stay up-to-date. We need our audience to keep an eye on software updates for the applications listed on our site and follow recent news about providers that we recommend. It's hard to keep up with the fast pace of the internet, but we try our best. If you spot an error, think a provider should not be listed, notice a qualified provider is missing, believe a browser plugin is no longer the best choice, or uncover any other issue, please let us know.
</div>
<div class="grid cards" style="margin:auto;max-width:800px;text-align:center;" markdown>

- [:simple-reddit: Join the r/PrivacyGuides Subreddit](https://www.reddit.com/r/privacyguides)
- [:simple-mastodon: Follow us on Mastodon](https://mastodon.social/@privacyguides){ rel=me }
- [:material-book-edit: Contribute to this website](https://github.com/privacyguides/privacyguides.org)
- [:simple-matrix: Chat with us on Matrix](https://matrix.to/#/#privacyguides:matrix.org)

</div>
<div style="padding:3em;text-align:center;" markdown>
## About Privacy Guides

**Privacy Guides** is a non-profit, socially motivated website that provides information for protecting your data security and privacy.

We do not make money from recommending certain products, and we do not use affiliate links.
<div class="grid cards" style="margin:auto;max-width:800px;text-align:center;" markdown>

- [:material-information-outline: Learn More About Us](about/)
- [:material-hand-coin-outline: Donation Info & Project Backers](about/donate/)

</div>
</div>
